package org.ow2.easybeans.deployment.annotations.helper;

import java.util.List;

import org.ow2.easybeans.deployment.annotations.metadata.ClassAnnotationMetadata;
import org.ow2.easybeans.deployment.annotations.metadata.EjbJarAnnotationMetadata;
import org.ow2.easybeans.deployment.annotations.metadata.LibrariesAnnotationMetadata;

/**
 * Complete existing metadata by libraries metadata.
 * @author Florent BENOIT
 */
public final class ExtraMetadataHelper {

    /**
     * Utility class.
     */
    private ExtraMetadataHelper() {
    }

    /**
     * Complete the given EJB metadata by the metadata found in the libraries.
     * @param ejbMetadata the medata to complete
     * @param libAnnotationMetadata the given data of the libraries.
     */
    public static void complete(final EjbJarAnnotationMetadata ejbMetadata,
            final LibrariesAnnotationMetadata libAnnotationMetadata) {

        // Nothing to complete
        if (libAnnotationMetadata == null) {
            return;
        }

        // List ?
        List<EjbJarAnnotationMetadata> extraMetaDataList = libAnnotationMetadata.getEjbJarAnnotationMetadataList();

        // Nothing to do
        if (extraMetaDataList == null) {
            return;
        }

        for (EjbJarAnnotationMetadata extraEjbJarAnnotationMetadata : extraMetaDataList) {
            for (ClassAnnotationMetadata classAnnotationMetadata : extraEjbJarAnnotationMetadata
                    .getClassAnnotationMetadataCollection()) {
                // Data exist for the EJB ?
                ClassAnnotationMetadata foundClassAnnotationMetadata = ejbMetadata
                        .getClassAnnotationMetadata(classAnnotationMetadata.getClassName());

                // Found something, continue
                if (foundClassAnnotationMetadata != null) {
                    continue;
                }

                // Not found, then complete
                ejbMetadata.addClassAnnotationMetadata(classAnnotationMetadata);

            }
        }
    }

}
